#!/usr/bin/perl
#
# Copyright (c) 2012, IDM
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are permitted
# provided that the following conditions are met:
#    * Redistributions of source code must retain the above copyright notice, this list of
#      conditions and the following disclaimer.
#    * Redistributions in binary form must reproduce the above copyright notice, this list
#      of conditions and the following disclaimer in the documentation and/or other materials
#      provided with the distribution.
#    * Neither the name of the IDM nor the names of its contributors may be used to endorse or
#      promote products derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
# FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

use strict;

use utf8;
use IDM::SkPublish::API;
use JSON;
use Data::Dumper;

package RequestHandler;

sub new {
    my $class = shift;
    return bless { }, $class;
}

sub prepareGetRequest {
    my ($this, $request) = @_;
    print $request->uri."\n";
    $request->header(Accept => 'application/json');
}

package main;

my ($baseUrl, $accessKey) = @ARGV;

my $ua = new LWP::UserAgent();
my $api = new IDM::SkPublish::API($baseUrl."/api/v1", $accessKey, $ua);
my $requestHandler = new RequestHandler;
$api->setRequestHandler($requestHandler);

print "*** Dictionaries\n";
my $dictionaries = decode_json($api->getDictionaries());
print Dumper($dictionaries);


my $dict = $dictionaries->[0];
print Dumper($dict);
my $dictCode = $dict->{"dictionaryCode"};

print "*** Search\n";
print "*** Result list\n";
my $results = decode_json($api->search($dictCode, "ca", 1, 1));
print Dumper($results);
print "*** Spell checking\n";
my $spellResults = decode_json($api->didYouMean($dictCode, "dorg", 3));
print Dumper($spellResults);
print "*** Best matching\n";
my $bestMatch = decode_json($api->searchFirst($dictCode, "ca", "html"));
print Dumper($bestMatch);

print "*** Nearby Entries\n";
my $nearbyEntries = decode_json($api->getNearbyEntries($dictCode, $bestMatch->{"entryId"}, 3));
print Dumper($nearbyEntries);

